@@ -358,14 +358,13 @@ class Optimizer:
                     and not interior_solution:
                 # increase radius
                 self.delta = self.get_option(Options.GAMMA2) * self.delta
-            elif self.tr_ratio <= self.get_option(Options.MU) \
-                    or interior_solution:
+            elif self.tr_ratio <= self.get_option(Options.MU):
                 # decrease radius
                 self.delta = np.nanmin([
                     self.delta * self.get_option(Options.GAMMA1),
                     nsx / 4
                 ])
-            return self.tr_ratio >= self.get_option(Options.MU)
+            return self.tr_ratio > 0.0
 
     def check_convergence(self, fval, x, grad) -> None:
         """
